An R list with named components representing a stochastic
Petri net (SPN). Should contain N$M, a vector representing
the initial marking of the net, N$Pre, a matrix representing
the LHS stoichiometries, N$Post, a matrix representing the
RHS stoichiometries, and N$h, a function representing the
rates of the reaction processes. N$h should have
first argument x, a vector representing the current state of
the system, and
second argument t, a scalar representing the current
simulation time (in the typical time-homogeneous case, N$h
will ignore this argument).
N$h may posses additional arguments, representing reaction rates, for example.